@@ -19,9 +19,9 @@
 ;; URL:      https://github.com/meedstrom/org-mem
 ;; Created:  2025-03-15
 ;; Keywords: text
-;; Package-Version: 20251021.1607
-;; Package-Revision: c3a0ba6a3aa4
-;; Package-Requires: ((emacs "29.1") (el-job "2.4.8") (llama "0.5.0"))
+;; Package-Version: 20251107.2038
+;; Package-Revision: 531a6b571ba0
+;; Package-Requires: ((emacs "29.1") (el-job "2.5.1") (llama "0.5.0"))
 
 ;;; Commentary:
 
@@ -60,6 +60,9 @@
 (declare-function org-id-alist-to-hash "org-id")
 (declare-function org-id-hash-to-alist "org-id")
 (define-obsolete-variable-alias 'org-mem-watch-dirs-exclude 'org-mem-exclude "0.13.0 (May 2025)")
+(unless (and (boundp 'el-job-old-internal-version)
+             (>= el-job-old-internal-version 100))
+  (error "Update to el-job 2.5.1+ to use this version of org-mem"))
 
 (defgroup org-mem nil "Fast info from a large amount of Org file contents."
   :group 'org)
@@ -302,6 +305,7 @@ Note: All tables cleared often, meant for memoizations."
   (description        nil :read-only t :type string-or-nil)
   (citation-p         nil :read-only t :type boolean)
   (nearby-id          nil :read-only t :type string-or-nil)
+  (supplement         nil :read-only t :type string-or-nil)
   (-internal-entry-id -1  :read-only t :type integer))
 
 (cl-defstruct org-mem-entry
@@ -1236,26 +1240,14 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
       (redisplay t))
     (let ((files (org-mem--list-files-from-fs)))
       (when files
-        (if (and (boundp 'el-job-old-internal-version)
-                 (>= el-job-old-internal-version 100))
-            ;; 2025-10-08: Use new argument :eval
-            (el-job-launch :id 'org-mem
-                           :if-busy 'takeover
-                           :inject-vars (append (org-mem--mk-work-vars) org-mem-inject-vars)
-                           :load-features (append '(org-mem-parser) org-mem-load-features)
-                           :eval org-mem-eval-forms
-                           :inputs files
-                           :funcall-per-input #'org-mem-parser--parse-file
-                           :callback #'org-mem--finalize-full-scan)
-          (when org-mem-eval-forms
-            (message "Update el-job for `org-mem-eval-forms' to have any effect"))
-          (el-job-launch :id 'org-mem
-                         :if-busy 'takeover
-                         :inject-vars (append (org-mem--mk-work-vars) org-mem-inject-vars)
-                         :load-features (append '(org-mem-parser) org-mem-load-features)
-                         :inputs files
-                         :funcall-per-input #'org-mem-parser--parse-file
-                         :callback #'org-mem--finalize-full-scan))
+        (el-job-launch :id 'org-mem
+                       :if-busy 'takeover
+                       :inject-vars (append (org-mem--mk-work-vars) org-mem-inject-vars)
+                       :load-features (append '(org-mem-parser) org-mem-load-features)
+                       :eval org-mem-eval-forms
+                       :inputs files
+                       :funcall-per-input #'org-mem-parser--parse-file
+                       :callback #'org-mem--finalize-full-scan)
         ;; While the subprocesses are parsing each file, let main process
         ;; spend this time caching the raw file contents.
         ;; It may seem that the subprocesses could just send the raw content
@@ -1294,8 +1286,7 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
   (clrhash org-mem--internal-entry-id<>links)
   (setq org-mem--title-collisions nil)
   (seq-let (bad-paths file-data entries links problems) parse-results
-    (when bad-paths
-      (org-mem--invalidate-file-names bad-paths))
+    (org-mem--invalidate-file-names bad-paths)
     (with-current-buffer
         (setq org-mem-scratch (get-buffer-create " *org-mem-scratch*" t))
       (dolist (fdata file-data)
@@ -1370,13 +1361,13 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
         ;; It would affect function `org-mem-id-by-title'.
         (puthash title id org-mem--title<>id)))))
 
-;; A "specially indexed" table is one that cannot be trivially updated when
-;; one file is re-scanned, since a given key in it may list values from
-;; multiple files.  So rather than try to find the particular values to
-;; remove, it's easiest to wipe and re-build.
-;; Note these tables are basically re-expressions of info that already exists.
 (defun org-mem--rebuild-specially-indexed-tables ()
-  "Rebuild table `org-mem--target<>links'."
+  "Rebuild table `org-mem--target<>links'.
+
+A \"specially indexed\" table is one that cannot be trivially updated when
+one file is re-scanned, since a given key in it may list values from
+multiple files.  So rather than try to find the particular values to
+remove, it's easiest to wipe and re-build."
   (setq org-mem--target<>old-links (copy-hash-table org-mem--target<>links))
   (clrhash org-mem--target<>links)
   (cl-loop
@@ -1501,22 +1492,23 @@ changing the meaning of \"~\" or \"~USER\", or runtime changes to
   "Scrub bad file names BAD in the tables that can pollute a reset.
 Notably, invalidate part of the cache used by `org-mem--truename-maybe'.
 If `org-mem-do-sync-with-org-id' t, also scrub `org-id-locations'."
-  ;; Example situation: File WILD is a symlink that changed destination.
-  ;; So cached TRUE led to a nonexistent file in the last scan.
-  ;; Now invalidate it so we cache a correct TRUE next time.
-  (maphash (lambda (wild true)
-             (when (member true bad)
-               (push wild bad)))
-           org-mem--wild-filename<>truename)
-  (dolist (bad bad)
-    (remhash bad org-mem--wild-filename<>truename))
-  (when (and org-mem-do-sync-with-org-id
-             (org-mem--try-ensure-org-id-table-p))
-    (setq org-id-locations
-          (org-id-alist-to-hash
-           (cl-loop for cell in (org-id-hash-to-alist org-id-locations)
-                    unless (member (car cell) bad)
-                    collect cell)))))
+  (when bad
+    ;; Example situation: File WILD is a symlink that changed destination.
+    ;; So cached TRUE led to a nonexistent file in the last scan.
+    ;; Now invalidate it so we cache a correct TRUE next time.
+    (maphash (lambda (wild true)
+               (when (member true bad)
+                 (push wild bad)))
+             org-mem--wild-filename<>truename)
+    (dolist (bad bad)
+      (remhash bad org-mem--wild-filename<>truename))
+    (when (and org-mem-do-sync-with-org-id
+               (org-mem--try-ensure-org-id-table-p))
+      (setq org-id-locations
+            (org-id-alist-to-hash
+             (cl-loop for cell in (org-id-hash-to-alist org-id-locations)
+                      unless (member (car cell) bad)
+                      collect cell))))))
 
 (defun org-mem--try-ensure-org-id-table-p ()
   "Coerce `org-id-locations' into hash table form, return nil on fail."
@@ -1796,7 +1788,7 @@ org-id-locations:
       (org-mem--scan-full))))
 
 
-(defvar org-mem--bump-int 18 "Not a version number, but bumped sometimes.")
+(defvar org-mem--bump-int 19 "Not a version number, but bumped sometimes.")
 (defmacro org-mem--def-whiny-alias (old new when removed-by)
   "Define function OLD as effectively an alias for NEW.
 Also, calling OLD will emit a deprecation warning the first time.
